@@ -281,11 +281,7 @@ void mosquittopp::user_data_set(void *userdata)
 
 int mosquittopp::socks5_set(const char *host, int port, const char *username, const char *password)
 {
-#ifdef WITH_SOCKS
 	return mosquitto_socks5_set(m_mosq, host, port, username, password);
-#else
-	return MOSQ_ERR_NOT_SUPPORTED;
-#endif
 }
 
 
