@@ -2,10 +2,7 @@
 
 # Test whether a SUBSCRIBE to a topic with QoS 0 results in the correct SUBACK packet.
 
-import subprocess
-import socket
 import time
-
 import inspect, os, sys
 # From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
 cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
