@@ -3,10 +3,6 @@
 # Test whether a retained PUBLISH to a topic with QoS 0 is sent with
 # retain=false to an already subscribed client.
 
-import subprocess
-import socket
-import time
-
 import inspect, os, sys
 # From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
 cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
