@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 
 import subprocess
-import socket
 import ssl
 import sys
 import time
@@ -15,7 +14,7 @@ if ssl.OPENSSL_VERSION_NUMBER < 0x10000000:
     exit(0)
 
 
-import inspect, os, sys
+import inspect, os
 # From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
 cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
 if cmd_subfolder not in sys.path:
@@ -56,7 +55,6 @@ try:
         pub = subprocess.Popen(['./c/08-tls-psk-bridge.test'], env=env, stdout=subprocess.PIPE)
         if pub.wait():
             raise ValueError
-            exit(1)
 
         if mosq_test.expect_packet(sock, "publish", publish_packet):
             rc = 0
