@@ -19,7 +19,8 @@ int main(int argc, char *argv[])
 	mosquitto_lib_init();
 
 	mosq = mosquitto_new("08-ssl-connect-crt-auth", true, NULL);
-	mosquitto_tls_set(mosq, "../ssl/fake-ca.crt", NULL, "../ssl/client.crt", "../ssl/client.key", NULL);
+	mosquitto_tls_opts_set(mosq, 1, "tlsv1", NULL);
+	mosquitto_tls_set(mosq, "../ssl/test-fake-root-ca.crt", NULL, "../ssl/client.crt", "../ssl/client.key", NULL);
 	mosquitto_connect_callback_set(mosq, on_connect);
 
 	rc = mosquitto_connect(mosq, "localhost", 1888, 60);
